.. fmriprep documentation master file, created by
   sphinx-quickstart on Mon May  9 09:04:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: links.rst
.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 3

   installation
   usage
   workflows
   outputs
   benchmarks
   spaces
   faq
   api
   changes
